==> tensorpc-0.11.8.tar.gz: tensorpc-0.11.8/tensorpc/examples/tutorials/02-components/2.8-ToggleButton.md <==
## ToggleButton

A toggle button is a button that can be toggled on (selected) or off (not selected).

### Basic Usage

```Python

from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        md = mui.Markdown()
        return mui.VBox([
            mui.ToggleButton("value0", name="ToggleButton", callback=lambda x: md.write(f"ToggleButton: :green[{x}]")),
            md,
        ])


```

### styles

```Python

from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        return mui.VBox([
            mui.ToggleButton("value0", name="Button"),
            mui.ToggleButton("value1", name="SmallButton").prop(size="small"),
            mui.ToggleButton("value2", name="PrimaryButton").prop(muiColor="primary"),
        ]).prop(alignItems="flex-start")
```

### Icons

```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout

svg_string = """
<svg
    xmlns="http://www.w3.org/2000/svg"
    fill="none"
    viewBox="0 0 24 24"
    stroke-width="1.5"
    stroke="currentColor"
>
    <path
    stroke-linecap="round"
    stroke-linejoin="round"
    d="M11.42 15.17L17.25 21A2.652 2.652 0 0021 17.25l-5.877-5.877M11.42 15.17l2.496-3.03c.317-.384.74-.626 1.208-.766M11.42 15.17l-4.655 5.653a2.548 2.548 0 11-3.586-3.586l6.837-5.63m5.108-.233c.55-.164 1.163-.188 1.743-.14a4.5 4.5 0 004.486-6.336l-3.276 3.277a3.004 3.004 0 01-2.25-2.25l3.276-3.276a4.5 4.5 0 00-6.336 4.486c.091 1.076-.071 2.264-.904 2.95l-.102.085m-1.745 1.437L5.909 7.5H4.5L2.25 3.75l1.5-1.5L7.5 4.5v1.409l4.26 4.26m-1.745 1.437l1.745-1.437m6.615 8.206L15.75 15.75M4.867 19.125h.008v.008h-.008v-.008z"
    />
</svg>
"""

class App:
    @mark_create_layout
    def my_layout(self):
        return mui.HBox([
            mui.ToggleButton(icon=mui.IconType.Add),
            mui.ToggleButton(icon=mui.IconType.Add).prop(size="small"),
            mui.ToggleButton(icon=mui.IconType.Add).prop(size="large"),
            mui.ToggleButton(icon=mui.IconType.Add).prop(disabled=True),
            mui.ToggleButton(icon=mui.IconType.Settings),
            mui.ToggleButton(icon=mui.IconType.Terminal).prop(muiColor="success"),
            mui.ToggleButton(icon=mui.IconType.Terminal).prop(muiColor="info"),
            mui.ToggleButton(icon=svg_string).prop(muiColor="info"),
            mui.ToggleButton(icon=svg_string).prop(muiColor="success"),

        ]).prop(alignItems="flex-start", flexWrap="wrap")
```

### Toggle Button Group

toggle button can be grouped to support Exclusive / Multiple selection.

When you use grouped toggle button, you must set the unique `value` prop of each toggle button.

* exclusive selection

```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        md = mui.Markdown()
        return mui.VBox([
            mui.ToggleButtonGroup([
                mui.ToggleButton("value0", name="Button0"),
                mui.ToggleButton("value1", name="Button1"),
                mui.ToggleButton("value2", name="Button2"),
            ], exclusive=True, callback=lambda x: md.write(f"ToggleButtonGroup (Exclusive): :green[{x}]")),
            mui.ToggleButtonGroup([
                mui.ToggleButton("value0", name="Button0"),
                mui.ToggleButton("value1", name="Button1"),
                mui.ToggleButton("value2", name="Button2"),
            ], exclusive=False, callback=lambda x: md.write(f"ToggleButtonGroup: :green[{x}]")),

            md,
        ])

```

==> tensorpc-0.13.0.tar.gz: tensorpc-0.13.0/tensorpc/examples/tutorials/02-components/2.8-ToggleButton.md <==
## ToggleButton

A toggle button is a button that can be toggled on (selected) or off (not selected).

### Basic Usage

```Python

from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        md = mui.Markdown()
        return mui.VBox([
            mui.ToggleButton(name="ToggleButton", callback=lambda x: md.write(f"ToggleButton: :green[{x}]")),
            md,
        ])


```

### styles

```Python

from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        return mui.VBox([
            mui.ToggleButton(name="Button"),
            mui.ToggleButton(name="SmallButton").prop(size="small"),
            mui.ToggleButton(name="PrimaryButton").prop(muiColor="primary"),
        ]).prop(alignItems="flex-start")
```

### Icons

```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout

svg_string = """
<svg
    xmlns="http://www.w3.org/2000/svg"
    fill="none"
    viewBox="0 0 24 24"
    stroke-width="1.5"
    stroke="currentColor"
>
    <path
    stroke-linecap="round"
    stroke-linejoin="round"
    d="M11.42 15.17L17.25 21A2.652 2.652 0 0021 17.25l-5.877-5.877M11.42 15.17l2.496-3.03c.317-.384.74-.626 1.208-.766M11.42 15.17l-4.655 5.653a2.548 2.548 0 11-3.586-3.586l6.837-5.63m5.108-.233c.55-.164 1.163-.188 1.743-.14a4.5 4.5 0 004.486-6.336l-3.276 3.277a3.004 3.004 0 01-2.25-2.25l3.276-3.276a4.5 4.5 0 00-6.336 4.486c.091 1.076-.071 2.264-.904 2.95l-.102.085m-1.745 1.437L5.909 7.5H4.5L2.25 3.75l1.5-1.5L7.5 4.5v1.409l4.26 4.26m-1.745 1.437l1.745-1.437m6.615 8.206L15.75 15.75M4.867 19.125h.008v.008h-.008v-.008z"
    />
</svg>
"""

class App:
    @mark_create_layout
    def my_layout(self):
        return mui.HBox([
            mui.ToggleButton(icon=mui.IconType.Add),
            mui.ToggleButton(icon=mui.IconType.Add).prop(size="small"),
            mui.ToggleButton(icon=mui.IconType.Add).prop(size="large"),
            mui.ToggleButton(icon=mui.IconType.Add).prop(disabled=True),
            mui.ToggleButton(icon=mui.IconType.Settings),
            mui.ToggleButton(icon=mui.IconType.Terminal).prop(muiColor="success"),
            mui.ToggleButton(icon=mui.IconType.Terminal).prop(muiColor="info"),
            mui.ToggleButton(icon=svg_string).prop(muiColor="info"),
            mui.ToggleButton(icon=svg_string).prop(muiColor="success"),

        ]).prop(alignItems="flex-start", flexWrap="wrap")
```

### Toggle Button Group

toggle button can be grouped to support Exclusive / Multiple selection.

When you use grouped toggle button, you must set the unique `value` prop of each toggle button.

* exclusive selection

```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout
class App:
    @mark_create_layout
    def my_layout(self):
        md = mui.Markdown()
        return mui.VBox([
            mui.ToggleButtonGroup([
                mui.GroupToggleButtonDef("value0", name="Button0"),
                mui.GroupToggleButtonDef("value1", name="Button1"),
                mui.GroupToggleButtonDef("value2", name="Button2"),
            ], exclusive=True, callback=lambda x: md.write(f"ToggleButtonGroup (Exclusive): :green[{x}]")),
            mui.ToggleButtonGroup([
                mui.GroupToggleButtonDef("value0", name="Button0"),
                mui.GroupToggleButtonDef("value1", name="Button1"),
                mui.GroupToggleButtonDef("value2", name="Button2"),
            ], exclusive=False, callback=lambda x: md.write(f"ToggleButtonGroup: :green[{x}]")),

            md,
        ])

```
